@@ -694,11 +694,7 @@ panel_action_button_connect_to_gsettings (PanelActionButton *button)
 }
 
 static void
-#if GTK_CHECK_VERSION (3, 0, 0)
 panel_action_button_style_updated (PanelActionButton *button)
-#else
-panel_action_button_style_set (PanelActionButton *button)
-#endif
 {
 	if (actions [button->priv->type].icon_name != NULL)
 		button_widget_set_icon_name (BUTTON_WIDGET (button), actions [button->priv->type].icon_name);
@@ -742,13 +738,8 @@ panel_action_button_load (PanelActionButtonType  type,
 
 	panel_action_button_connect_to_gsettings (button);
 
-#if GTK_CHECK_VERSION (3, 0, 0)
 	g_signal_connect (button, "style-updated",
 			  G_CALLBACK (panel_action_button_style_updated), NULL);
-#else
-	g_signal_connect (button, "style-set",
-			  G_CALLBACK (panel_action_button_style_set), NULL);
-#endif
 }
 
 void
